@@ -14,7 +14,9 @@
 
 // This is an implementation of a cAdvisor REST API in Go.
 // To use it, create a client (replace the URL with your actual cAdvisor REST endpoint):
-//   client, err := client.NewClient("http://192.168.59.103:8080/")
+//
+//	client, err := client.NewClient("http://192.168.59.103:8080/")
+//
 // Then, the client interface exposes go methods corresponding to the REST endpoints.
 package client
 
@@ -23,20 +25,18 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"path"
 	"strings"
 
-	"github.com/google/cadvisor/info/v1"
+	v1 "github.com/google/cadvisor/info/v1"
 
-	"github.com/golang/glog"
-	"time"
+	"k8s.io/klog/v2"
 )
 
 // Client represents the base URL for a cAdvisor client.
 type Client struct {
-	baseUrl    string
+	baseURL    string
 	httpClient *http.Client
 }
 
@@ -45,29 +45,22 @@ func NewClient(url string) (*Client, error) {
 	return newClient(url, http.DefaultClient)
 }
 
-// NewClientWithTimeout returns a new v1.3 client with the specified base URL and http client timeout.
-func NewClientWithTimeout(url string, timeout time.Duration) (*Client, error) {
-	return newClient(url, &http.Client{
-		Timeout: timeout,
-	})
-}
-
 func newClient(url string, client *http.Client) (*Client, error) {
 	if !strings.HasSuffix(url, "/") {
 		url += "/"
 	}
 
 	return &Client{
-		baseUrl:    fmt.Sprintf("%sapi/v1.3/", url),
+		baseURL:    fmt.Sprintf("%sapi/v1.3/", url),
 		httpClient: client,
 	}, nil
 }
 
 // Returns all past events that satisfy the request
-func (self *Client) EventStaticInfo(name string) (einfo []*v1.Event, err error) {
-	u := self.eventsInfoUrl(name)
+func (c *Client) EventStaticInfo(name string) (einfo []*v1.Event, err error) {
+	u := c.eventsInfoURL(name)
 	ret := new([]*v1.Event)
-	if err = self.httpGetJsonData(ret, nil, u, "event info"); err != nil {
+	if err = c.httpGetJSONData(ret, nil, u, "event info"); err != nil {
 		return
 	}
 	einfo = *ret
@@ -76,9 +69,9 @@ func (self *Client) EventStaticInfo(name string) (einfo []*v1.Event, err error)
 
 // Streams all events that occur that satisfy the request into the channel
 // that is passed
-func (self *Client) EventStreamingInfo(name string, einfo chan *v1.Event) (err error) {
-	u := self.eventsInfoUrl(name)
-	if err = self.getEventStreamingData(u, einfo); err != nil {
+func (c *Client) EventStreamingInfo(name string, einfo chan *v1.Event) (err error) {
+	u := c.eventsInfoURL(name)
+	if err = c.getEventStreamingData(u, einfo); err != nil {
 		return
 	}
 	return nil
@@ -87,10 +80,10 @@ func (self *Client) EventStreamingInfo(name string, einfo chan *v1.Event) (err e
 // MachineInfo returns the JSON machine information for this client.
 // A non-nil error result indicates a problem with obtaining
 // the JSON machine information data.
-func (self *Client) MachineInfo() (minfo *v1.MachineInfo, err error) {
-	u := self.machineInfoUrl()
+func (c *Client) MachineInfo() (minfo *v1.MachineInfo, err error) {
+	u := c.machineInfoURL()
 	ret := new(v1.MachineInfo)
-	if err = self.httpGetJsonData(ret, nil, u, "machine info"); err != nil {
+	if err = c.httpGetJSONData(ret, nil, u, "machine info"); err != nil {
 		return
 	}
 	minfo = ret
@@ -99,10 +92,10 @@ func (self *Client) MachineInfo() (minfo *v1.MachineInfo, err error) {
 
 // ContainerInfo returns the JSON container information for the specified
 // container and request.
-func (self *Client) ContainerInfo(name string, query *v1.ContainerInfoRequest) (cinfo *v1.ContainerInfo, err error) {
-	u := self.containerInfoUrl(name)
+func (c *Client) ContainerInfo(name string, query *v1.ContainerInfoRequest) (cinfo *v1.ContainerInfo, err error) {
+	u := c.containerInfoURL(name)
 	ret := new(v1.ContainerInfo)
-	if err = self.httpGetJsonData(ret, query, u, fmt.Sprintf("container info for %q", name)); err != nil {
+	if err = c.httpGetJSONData(ret, query, u, fmt.Sprintf("container info for %q", name)); err != nil {
 		return
 	}
 	cinfo = ret
@@ -110,10 +103,10 @@ func (self *Client) ContainerInfo(name string, query *v1.ContainerInfoRequest) (
 }
 
 // Returns the information about all subcontainers (recursive) of the specified container (including itself).
-func (self *Client) SubcontainersInfo(name string, query *v1.ContainerInfoRequest) ([]v1.ContainerInfo, error) {
+func (c *Client) SubcontainersInfo(name string, query *v1.ContainerInfoRequest) ([]v1.ContainerInfo, error) {
 	var response []v1.ContainerInfo
-	url := self.subcontainersInfoUrl(name)
-	err := self.httpGetJsonData(&response, query, url, fmt.Sprintf("subcontainers container info for %q", name))
+	url := c.subcontainersInfoURL(name)
+	err := c.httpGetJSONData(&response, query, url, fmt.Sprintf("subcontainers container info for %q", name))
 	if err != nil {
 		return []v1.ContainerInfo{}, err
 
@@ -123,10 +116,10 @@ func (self *Client) SubcontainersInfo(name string, query *v1.ContainerInfoReques
 
 // Returns the JSON container information for the specified
 // Docker container and request.
-func (self *Client) DockerContainer(name string, query *v1.ContainerInfoRequest) (cinfo v1.ContainerInfo, err error) {
-	u := self.dockerInfoUrl(name)
+func (c *Client) DockerContainer(name string, query *v1.ContainerInfoRequest) (cinfo v1.ContainerInfo, err error) {
+	u := c.dockerInfoURL(name)
 	ret := make(map[string]v1.ContainerInfo)
-	if err = self.httpGetJsonData(&ret, query, u, fmt.Sprintf("Docker container info for %q", name)); err != nil {
+	if err = c.httpGetJSONData(&ret, query, u, fmt.Sprintf("Docker container info for %q", name)); err != nil {
 		return
 	}
 	if len(ret) != 1 {
@@ -140,10 +133,10 @@ func (self *Client) DockerContainer(name string, query *v1.ContainerInfoRequest)
 }
 
 // Returns the JSON container information for all Docker containers.
-func (self *Client) AllDockerContainers(query *v1.ContainerInfoRequest) (cinfo []v1.ContainerInfo, err error) {
-	u := self.dockerInfoUrl("/")
+func (c *Client) AllDockerContainers(query *v1.ContainerInfoRequest) (cinfo []v1.ContainerInfo, err error) {
+	u := c.dockerInfoURL("/")
 	ret := make(map[string]v1.ContainerInfo)
-	if err = self.httpGetJsonData(&ret, query, u, "all Docker containers info"); err != nil {
+	if err = c.httpGetJSONData(&ret, query, u, "all Docker containers info"); err != nil {
 		return
 	}
 	cinfo = make([]v1.ContainerInfo, 0, len(ret))
@@ -153,27 +146,27 @@ func (self *Client) AllDockerContainers(query *v1.ContainerInfoRequest) (cinfo [
 	return
 }
 
-func (self *Client) machineInfoUrl() string {
-	return self.baseUrl + path.Join("machine")
+func (c *Client) machineInfoURL() string {
+	return c.baseURL + path.Join("machine")
 }
 
-func (self *Client) containerInfoUrl(name string) string {
-	return self.baseUrl + path.Join("containers", name)
+func (c *Client) containerInfoURL(name string) string {
+	return c.baseURL + path.Join("containers", name)
 }
 
-func (self *Client) subcontainersInfoUrl(name string) string {
-	return self.baseUrl + path.Join("subcontainers", name)
+func (c *Client) subcontainersInfoURL(name string) string {
+	return c.baseURL + path.Join("subcontainers", name)
 }
 
-func (self *Client) dockerInfoUrl(name string) string {
-	return self.baseUrl + path.Join("docker", name)
+func (c *Client) dockerInfoURL(name string) string {
+	return c.baseURL + path.Join("docker", name)
 }
 
-func (self *Client) eventsInfoUrl(name string) string {
-	return self.baseUrl + path.Join("events", name)
+func (c *Client) eventsInfoURL(name string) string {
+	return c.baseURL + path.Join("events", name)
 }
 
-func (self *Client) httpGetJsonData(data, postData interface{}, url, infoName string) error {
+func (c *Client) httpGetJSONData(data, postData interface{}, url, infoName string) error {
 	var resp *http.Response
 	var err error
 
@@ -182,9 +175,9 @@ func (self *Client) httpGetJsonData(data, postData interface{}, url, infoName st
 		if marshalErr != nil {
 			return fmt.Errorf("unable to marshal data: %v", marshalErr)
 		}
-		resp, err = self.httpClient.Post(url, "application/json", bytes.NewBuffer(data))
+		resp, err = c.httpClient.Post(url, "application/json", bytes.NewBuffer(data))
 	} else {
-		resp, err = self.httpClient.Get(url)
+		resp, err = c.httpClient.Get(url)
 	}
 	if err != nil {
 		return fmt.Errorf("unable to get %q from %q: %v", infoName, url, err)
@@ -193,7 +186,7 @@ func (self *Client) httpGetJsonData(data, postData interface{}, url, infoName st
 		return fmt.Errorf("received empty response for %q from %q", infoName, url)
 	}
 	defer resp.Body.Close()
-	body, err := ioutil.ReadAll(resp.Body)
+	body, err := io.ReadAll(resp.Body)
 	if err != nil {
 		err = fmt.Errorf("unable to read all %q from %q: %v", infoName, url, err)
 		return err
@@ -208,12 +201,12 @@ func (self *Client) httpGetJsonData(data, postData interface{}, url, infoName st
 	return nil
 }
 
-func (self *Client) getEventStreamingData(url string, einfo chan *v1.Event) error {
+func (c *Client) getEventStreamingData(url string, einfo chan *v1.Event) error {
 	req, err := http.NewRequest("GET", url, nil)
 	if err != nil {
 		return err
 	}
-	resp, err := self.httpClient.Do(req)
+	resp, err := c.httpClient.Do(req)
 	if err != nil {
 		return err
 	}
@@ -230,7 +223,7 @@ func (self *Client) getEventStreamingData(url string, einfo chan *v1.Event) erro
 				break
 			}
 			// if called without &stream=true will not be able to parse event and will trigger fatal
-			glog.Fatalf("Received error %v", err)
+			klog.Fatalf("Received error %v", err)
 		}
 		einfo <- m
 	}
