@@ -11,6 +11,7 @@
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
+
 package devicemapper
 
 import (
@@ -35,7 +36,7 @@ func TestRefresh(t *testing.T) {
 		thinLsOutput    map[string]uint64
 		thinLsErr       error
 		expectedError   bool
-		deviceId        string
+		deviceID        string
 		expectedUsage   uint64
 	}{
 		{
@@ -54,19 +55,19 @@ func TestRefresh(t *testing.T) {
 			},
 			thinLsOutput:  usage,
 			expectedError: false,
-			deviceId:      "2",
+			deviceID:      "2",
 			expectedUsage: 23456,
 		},
 		{
 			name: "no existing reservation - ok",
 			dmsetupCommands: []fake.DmsetupCommand{
 				{Name: "status", Result: "0 75497472 thin-pool 65 327/524288 14092/589824 - rw no_discard_passdown error_if_no_space - ", Err: nil}, // status check
-				{Name: "message", Result: "", Err: nil},                                                                                             // make reservation
-				{Name: "message", Result: "", Err: nil},                                                                                             // release reservation
+				{Name: "message", Result: "", Err: nil}, // make reservation
+				{Name: "message", Result: "", Err: nil}, // release reservation
 			},
 			thinLsOutput:  usage,
 			expectedError: false,
-			deviceId:      "2",
+			deviceID:      "2",
 			expectedUsage: 23456,
 		},
 		{
@@ -83,7 +84,7 @@ func TestRefresh(t *testing.T) {
 			},
 			thinLsOutput:  usage,
 			expectedError: false,
-			deviceId:      "3",
+			deviceID:      "3",
 			expectedUsage: 34567,
 		},
 		{
@@ -149,9 +150,9 @@ func TestRefresh(t *testing.T) {
 			continue
 		}
 
-		actualUsage, err := watcher.GetUsage(tc.deviceId)
+		actualUsage, err := watcher.GetUsage(tc.deviceID)
 		if err != nil {
-			t.Errorf("%v: device ID not found: %v", tc.deviceId, err)
+			t.Errorf("%v: device ID not found: %v", tc.deviceID, err)
 			continue
 		}
 
