@@ -17,8 +17,9 @@ package main
 import (
 	"flag"
 
+	"k8s.io/klog/v2"
+
 	"github.com/google/cadvisor/utils/oomparser"
-	"k8s.io/klog"
 )
 
 // demonstrates how to run oomparser.OomParser to get OomInstance information
