@@ -23,57 +23,33 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-const startLine = "ruby invoked oom-killer: gfp_mask=0x201da, order=0, oom_score_adj=0"
-const endLine = "Killed process 19667 (evil-program2) total-vm:1460016kB, anon-rss:1414008kB, file-rss:4kB"
-const containerLine = "Task in /mem2 killed as a result of limit of /mem3"
-const containerLogFile = "containerOomExampleLog.txt"
-const systemLogFile = "systemOomExampleLog.txt"
+const (
+	startLine           = "ruby invoked oom-killer: gfp_mask=0x201da, order=0, oom_score_adj=0"
+	endLine             = "Killed process 19667 (evil-program2) total-vm:1460016kB, anon-rss:1414008kB, file-rss:4kB"
+	legacyContainerLine = "Task in /mem2 killed as a result of limit of /mem3"
+	containerLine       = "oom-kill:constraint=CONSTRAINT_MEMCG,nodemask=(null),cpuset=ef807430361e6e82b45db92e2e9b6fbec98f419b12c591e655c1a725565e73a8,mems_allowed=0,oom_memcg=/kubepods/burstable/podfbdfe8e3-1c87-4ff2-907c-b2ec8e25d012,task_memcg=/kubepods/burstable/podfbdfe8e3-1c87-4ff2-907c-b2ec8e25d012/ef807430361e6e82b45db92e2e9b6fbec98f419b12c591e655c1a725565e73a8,task=manager,pid=966,uid=0"
+)
 
-func createExpectedContainerOomInstance(t *testing.T) *OomInstance {
-	const longForm = "Jan _2 15:04:05 2006"
-	deathTime, err := time.ParseInLocation(longForm, fmt.Sprintf("Jan  5 15:19:27 %d", time.Now().Year()), time.Local)
-	if err != nil {
-		t.Fatalf("could not parse expected time when creating expected container oom instance. Had error %v", err)
-		return nil
-	}
-	return &OomInstance{
-		Pid:                 13536,
-		ProcessName:         "memorymonster",
-		TimeOfDeath:         deathTime,
-		ContainerName:       "/mem2",
-		VictimContainerName: "/mem2",
-	}
-}
-
-func createExpectedSystemOomInstance(t *testing.T) *OomInstance {
-	const longForm = "Jan _2 15:04:05 2006"
-	deathTime, err := time.ParseInLocation(longForm, fmt.Sprintf("Jan 28 19:58:45 %d", time.Now().Year()), time.Local)
-	if err != nil {
-		t.Fatalf("could not parse expected time when creating expected system oom instance. Had error %v", err)
-		return nil
-	}
-	return &OomInstance{
-		Pid:                 1532,
-		ProcessName:         "badsysprogram",
-		TimeOfDeath:         deathTime,
-		ContainerName:       "/",
-		VictimContainerName: "",
-	}
-}
-
-func TestGetContainerName(t *testing.T) {
+func TestGetLegacyContainerName(t *testing.T) {
 	currentOomInstance := new(OomInstance)
-	err := getContainerName(startLine, currentOomInstance)
+	finished, err := getContainerName(startLine, currentOomInstance)
 	if err != nil {
 		t.Errorf("bad line fed to getContainerName should yield no error, but had error %v", err)
 	}
+	if finished {
+		t.Errorf("bad line fed to getContainerName should not result in a finished oom log, but it did")
+	}
 	if currentOomInstance.ContainerName != "" {
 		t.Errorf("bad line fed to getContainerName yielded no container name but set it to %s", currentOomInstance.ContainerName)
 	}
-	err = getContainerName(containerLine, currentOomInstance)
+	finished, err = getContainerName(legacyContainerLine, currentOomInstance)
 	if err != nil {
 		t.Errorf("container line fed to getContainerName should yield no error, but had error %v", err)
 	}
+	if finished {
+		t.Errorf("getContainerName with the legacy log line should not result in a finished oom log, but it did")
+
+	}
 	if currentOomInstance.ContainerName != "/mem2" {
 		t.Errorf("getContainerName should have set containerName to /mem2, not %s", currentOomInstance.ContainerName)
 	}
@@ -82,6 +58,43 @@ func TestGetContainerName(t *testing.T) {
 	}
 }
 
+func TestGetContainerName(t *testing.T) {
+	currentOomInstance := new(OomInstance)
+	finished, err := getContainerName(startLine, currentOomInstance)
+	if err != nil {
+		t.Errorf("bad line fed to getContainerName should yield no error, but had error %v", err)
+	}
+	if finished {
+		t.Errorf("bad line fed to getContainerName should not result in a finished oom log, but it did")
+	}
+	if currentOomInstance.ContainerName != "" {
+		t.Errorf("bad line fed to getContainerName yielded no container name but set it to %s", currentOomInstance.ContainerName)
+	}
+	finished, err = getContainerName(containerLine, currentOomInstance)
+	if err != nil {
+		t.Errorf("container line fed to getContainerName should yield no error, but had error %v", err)
+	}
+	if !finished {
+		t.Errorf("getContainerName with the complete log line should result in a finished oom log, but it did not")
+
+	}
+	if currentOomInstance.ContainerName != "/kubepods/burstable/podfbdfe8e3-1c87-4ff2-907c-b2ec8e25d012/ef807430361e6e82b45db92e2e9b6fbec98f419b12c591e655c1a725565e73a8" {
+		t.Errorf("getContainerName should have set containerName to /kubepods/burstable/podfbdfe8e3-1c87-4ff2-907c-b2ec8e25d012/ef807430361e6e82b45db92e2e9b6fbec98f419b12c591e655c1a725565e73a8, not %s", currentOomInstance.ContainerName)
+	}
+	if currentOomInstance.VictimContainerName != "/kubepods/burstable/podfbdfe8e3-1c87-4ff2-907c-b2ec8e25d012" {
+		t.Errorf("getContainerName should have set victimContainerName to /kubepods/burstable/podfbdfe8e3-1c87-4ff2-907c-b2ec8e25d012, not %s", currentOomInstance.VictimContainerName)
+	}
+	if currentOomInstance.Pid != 966 {
+		t.Errorf("getContainerName should have set Pid to 966, not %d", currentOomInstance.Pid)
+	}
+	if currentOomInstance.ProcessName != "manager" {
+		t.Errorf("getContainerName should have set ProcessName to manager, not %s", currentOomInstance.ProcessName)
+	}
+	if currentOomInstance.Constraint != "CONSTRAINT_MEMCG" {
+		t.Errorf("getContainerName should have set ProcessName to CONSTRAINT_MEMCG, not %s", currentOomInstance.Constraint)
+	}
+}
+
 func TestGetProcessNamePid(t *testing.T) {
 	currentOomInstance := new(OomInstance)
 	couldParseLine, err := getProcessNamePid(startLine, currentOomInstance)
@@ -123,7 +136,9 @@ func TestLastLineRegex(t *testing.T) {
 	for _, name := range processNames {
 		line := fmt.Sprintf("Jan 21 22:01:49 localhost kernel: [62279.421192] Killed process 1234 (%s) total-vm:1460016kB, anon-rss:1414008kB, file-rss:4kB", name)
 		oomInfo := &OomInstance{}
-		getProcessNamePid(line, oomInfo)
+		isPid, err := getProcessNamePid(line, oomInfo)
+		assert.True(t, isPid)
+		assert.NoError(t, err)
 		assert.Equal(t, 1234, oomInfo.Pid)
 		assert.Equal(t, name, oomInfo.ProcessName)
 	}
@@ -300,7 +315,7 @@ func TestStreamOOMs(t *testing.T) {
 				ProcessName:         "badsysprogram",
 				TimeOfDeath:         testTime,
 				ContainerName:       "/",
-				VictimContainerName: "",
+				VictimContainerName: "/",
 			}},
 		},
 		{ // Multiple OOMs
@@ -435,6 +450,7 @@ func TestStreamOOMs(t *testing.T) {
 	}
 
 	for _, pair := range testPairs {
+		pair := pair
 		go func() {
 			for _, x := range pair.in {
 				writeAll(x.msgs, x.time)
